@@ -35,6 +35,6 @@ def validate_resume(
         validation_flag = True
         return info_message, validation_flag
     else:
-        warning_message = f"The resume in location {yaml_resume} does not validate to the resume_schema\n\tErrors: {validation_error}".format(validation_error=validator.errors)  # type: ignore
+        warning_message = "The resume in location {yaml_resume} does not validate to the resume_schema\n\tErrors: {validation_error}".format(yaml_resume=yaml_resume, validation_error=validator.errors)  # type: ignore
         validation_flag = False
         return warning_message, validation_flag
